@@ -126,12 +126,12 @@ def template_from_file(filename: str, **globals) -> Template:  # pylint: disable
 	with importlib_resources.path("repo_helper.blocks", filename) as shields_block_template_file:
 		template_text = PathPlus(shields_block_template_file).read_text().replace("\\\n", '')
 
-	environment = Environment(loader=BaseLoader(), undefined=StrictUndefined)  # nosec: B701
+		environment = Environment(loader=BaseLoader(), undefined=StrictUndefined)  # nosec: B701
 
-	if globals:
-		return environment.from_string(template_text, globals=globals)
-	else:
-		return environment.from_string(template_text)
+		if globals:
+			return environment.from_string(template_text, globals=globals)
+		else:
+			return environment.from_string(template_text)
 
 
 @functools.lru_cache(1)
@@ -460,7 +460,7 @@ class ShieldsBlock:
 		self.make_wheel_shield = make_docs_wheel_shield
 		self.make_pypi_downloads_shield = make_docs_pypi_downloads_shield
 
-	def make(self) -> str:
+	def make(self) -> StringList:
 		"""
 		Constructs the contents of the shields block.
 		"""
@@ -581,4 +581,4 @@ class ShieldsBlock:
 		buf.append(".. end shields")
 		# buf.blankline(ensure_single=True)
 
-		return str(buf)
+		return buf
