@@ -26,9 +26,11 @@ Configuration options.
 # stdlib
 import json
 import re
-from typing import Any, Dict, List, Mapping, MutableMapping, Optional, Sequence, Set, Union
+from io import StringIO
+from typing import Any, Callable, Dict, Iterable, List, Mapping, MutableMapping, Optional, Sequence, Set, Union
 
 # 3rd party
+import click
 from configconfig.metaclass import ConfigVarMeta
 from configconfig.parser import Parser
 from configconfig.utils import make_schema
@@ -36,7 +38,7 @@ from domdf_python_tools.compat import importlib_resources
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.typing import PathLike
 from domdf_python_tools.versions import Version
-from natsort import natsorted  # type: ignore
+from natsort import natsorted
 from ruamel.yaml import YAML
 
 # this package
@@ -52,9 +54,16 @@ from repo_helper.configuration import (
 		testing,
 		travis
 		)
-from repo_helper.configuration.conda_anaconda import conda_channels, conda_description, conda_extras, enable_conda
+from repo_helper.configuration.conda_anaconda import (
+		conda_channels,
+		conda_description,
+		conda_extras,
+		enable_conda,
+		primary_conda_channel
+		)
 from repo_helper.configuration.documentation import (
 		docs_dir,
+		docs_fail_on_warning,
 		docs_url,
 		enable_docs,
 		extra_sphinx_extensions,
@@ -113,16 +122,20 @@ from repo_helper.configuration.packaging import (
 		platforms,
 		py_modules,
 		setup_pre,
-		use_experimental_backend
+		use_experimental_backend,
+		use_whey
 		)
 from repo_helper.configuration.python_versions_ import (
 		default_python_versions,
 		python_deploy_version,
-		python_versions
+		python_versions,
+		requires_python,
+		third_party_version_matrix
 		)
 from repo_helper.configuration.testing import (
 		enable_devmode,
 		enable_tests,
+		min_coverage,
 		mypy_deps,
 		mypy_plugins,
 		mypy_version,
@@ -138,12 +151,7 @@ from repo_helper.configuration.travis import (
 		travis_extra_install_pre,
 		travis_ubuntu_version
 		)
-from repo_helper.configuration.utils import (
-		get_gh_actions_python_versions,
-		get_tox_python_versions,
-		get_tox_travis_python_versions,
-		parse_extras
-		)
+from repo_helper.configuration.utils import get_tox_python_versions, parse_extras
 from repo_helper.utils import no_dev_versions
 
 __all__ = [
@@ -154,6 +162,7 @@ __all__ = [
 		"author",
 		"classifiers",
 		"conda_channels",
+		"primary_conda_channel",
 		"conda_extras",
 		"conda_description",
 		"console_scripts",
@@ -171,9 +180,7 @@ __all__ = [
 		"exclude_files",
 		"extra_sphinx_extensions",
 		"extras_require",
-		"get_gh_actions_python_versions",
 		"get_tox_python_versions",
-		"get_tox_travis_python_versions",
 		"html_context",
 		"html_theme_options",
 		"imgbot_ignore",
@@ -196,6 +203,7 @@ __all__ = [
 		"pypi_name",
 		"python_deploy_version",
 		"python_versions",
+		"requires_python",
 		"repo_name",
 		"rtfd_author",
 		"setup_pre",
@@ -227,16 +235,24 @@ __all__ = [
 		"assignee",
 		"YamlEditor",
 		"docs_url",
+		"third_party_version_matrix",
+		"entry_points",
+		"min_coverage",
+		"docs_fail_on_warning",
+		"use_whey",
 		]
 
 
-def parse_yaml(repo_path: PathLike) -> Dict:
+def parse_yaml(repo_path: PathLike, allow_unknown_keys: bool = False) -> Dict:
 	"""
 	Parse configuration values from ``repo_helper.yml``.
 
 	:param repo_path: Path to the repository root.
+	:param allow_unknown_keys: Whether unknown keys should be allowed in the configuration file.
 
 	:returns: Mapping of configuration keys to values.
+
+	.. versionchanged:: 2021.2.18  Added the ``allow_unknown_keys`` argument.
 	"""
 
 	repo_path = PathPlus(repo_path)
@@ -254,7 +270,7 @@ def parse_yaml(repo_path: PathLike) -> Dict:
 			if not re.match("^(use_travis|travis_pypi_secure|travis_site)", line)
 			])
 
-	parser = RepoHelperParser(allow_unknown_keys=False)
+	parser = RepoHelperParser(allow_unknown_keys=allow_unknown_keys)
 	config_vars = parser.run(config_file)
 	config_file.write_clean(config_file.read_text())
 
@@ -314,6 +330,13 @@ class RepoHelperParser(Parser):
 		# Python Versions
 		versions = no_dev_versions(parsed_config_vars["python_versions"])
 		parsed_config_vars["min_py_version"] = min_py_version = versions[0]
+
+		if parsed_config_vars["requires_python"] is None:
+			if min_py_version in {"3.6", 3.6}:
+				parsed_config_vars["requires_python"] = "3.6.1"
+			else:
+				parsed_config_vars["requires_python"] = min_py_version
+
 		smallest_py_version = Version.from_str(min_py_version)
 		for py_version in versions:
 			try:
@@ -330,9 +353,6 @@ class RepoHelperParser(Parser):
 		py_versions = parsed_config_vars["python_versions"]
 		tox_py_versions = get_tox_python_versions(py_versions)
 		parsed_config_vars["tox_py_versions"] = tox_py_versions
-		gh_actions_versions = get_gh_actions_python_versions(py_versions, tox_py_versions)
-		parsed_config_vars["tox_travis_versions"] = gh_actions_versions
-		parsed_config_vars["gh_actions_versions"] = gh_actions_versions
 
 		if (repo_path / parsed_config_vars["import_name"].replace('.', '/') / "py.typed").is_file():
 			parsed_config_vars["classifiers"].append("Typing :: Typed")
@@ -346,6 +366,11 @@ class RepoHelperParser(Parser):
 			url = f"https://{parsed_config_vars['repo_name'].lower()}.readthedocs.io/en/latest"
 			parsed_config_vars["docs_url"] = url
 
+		parsed_config_vars["conda_channels"] = sorted({
+				*parsed_config_vars["conda_channels"],
+				parsed_config_vars["primary_conda_channel"],
+				})
+
 		return parsed_config_vars
 
 
@@ -359,7 +384,7 @@ def dump_schema() -> Dict[str, Any]:
 
 	with importlib_resources.path(repo_helper, "repo_helper_schema.json") as schema_file:
 		PathPlus(schema_file).write_clean(json.dumps(schema, indent=2))
-		print(f"Wrote schema to {schema_file}")
+		click.echo(f"Wrote schema to {schema_file}")
 
 	return schema
 
@@ -396,6 +421,24 @@ class YamlEditor(YAML):
 		filename = PathPlus(filename)
 		return self.load(filename.read_text())
 
+	def dumps(  # noqa: D102
+		self,
+		data: Union[MutableMapping, Sequence],
+		*,
+		explicit_start: bool = True,
+		**kwargs,
+		) -> str:
+		original_exp_start = self.explicit_start
+
+		try:
+			fp = StringIO()
+			self.explicit_start = explicit_start
+			self.dump(data, fp, **kwargs)
+			return fp.getvalue()
+
+		finally:
+			self.explicit_start = original_exp_start
+
 	def dump_to_file(self, data: Union[MutableMapping, Sequence], filename: PathLike, mode: str = 'w'):
 		"""
 		Dump the given data to the specified file.
@@ -405,25 +448,18 @@ class YamlEditor(YAML):
 		:param mode:
 		"""
 
-		# TODO: dump to StringIO and use write_clean
+		filename = PathPlus(filename)
 
-		explicit_start = self.explicit_start
+		if 'w' in mode:
+			filename.write_lines([
+					"# Configuration for 'repo_helper' (https://github.com/domdfcoding/repo_helper)",
+					self.dumps(data, explicit_start=True),
+					])
 
-		try:
-			filename = PathPlus(filename)
-
-			with filename.open(mode) as fp:
-
-				if 'w' in mode:
-					self.explicit_start = True
-				elif 'a' in mode:
-					self.explicit_start = False
-					fp.write('\n')
-
-				self.dump(data, fp)
-
-		finally:
-			self.explicit_start = explicit_start
+		elif 'a' in mode:
+			with filename.open('a') as fp:
+				fp.write('\n')
+				fp.write(self.dumps(data, explicit_start=False))
 
 	def update_key(
 			self,
@@ -444,6 +480,18 @@ class YamlEditor(YAML):
 
 		data = self.load_file(filename)
 
+		if not isinstance(data, dict):
+			raise TypeError("'update_key' can only be used with mappings.")
+
+		if isinstance(new_value, str) or not isinstance(new_value, Iterable):
+			if key in data:
+				data[key] = new_value
+				self.dump_to_file(data, filename, mode='w')
+			else:
+				self.dump_to_file({key: new_value}, filename, mode='a')
+
+		sort_func: Callable[[Iterable], Iterable]
+
 		if sort:
 			sort_func = natsorted
 		else:
@@ -458,4 +506,4 @@ class YamlEditor(YAML):
 			data[key] = sort_func({*data[key], *new_value})  # type: ignore
 			self.dump_to_file(data, filename, mode='w')
 		else:
-			self.dump_to_file({key: sort_func(new_value)}, filename, mode='a')
+			self.dump_to_file({key: sort_func(new_value)}, filename, mode='a')  # type: ignore
