@@ -40,6 +40,7 @@ __all__ = [
 		"enable_devmode",
 		"mypy_version",
 		"tox_unmanaged",
+		"min_coverage",
 		]
 
 
@@ -192,11 +193,32 @@ class mypy_version(ConfigVar):  # noqa
 	.. code-block:: yaml
 
 		mypy_version: 0.790
+
+	.. versionchanged:: 2021.2.18  The default is now ``0.800``
 	"""
 
 	dtype = Union[str, float]
 	rtype = str
-	default = "0.790"
+	default = "0.800"
+	category: str = "testing"
+
+
+class min_coverage(ConfigVar):  # noqa
+	"""
+	The minimum permitted test coverage percentage.
+
+	Example:
+
+	.. code-block:: yaml
+
+		mypy_version: 0.790
+
+	.. versionadded:: 2020.1.27
+	"""
+
+	dtype = Union[str, float]
+	rtype = str
+	default = "80"
 	category: str = "testing"
 
 
