@@ -26,7 +26,6 @@ Configuration for documentation with
 #
 
 # stdlib
-import functools
 import logging
 import os.path
 import pathlib
@@ -132,7 +131,7 @@ class DocRequirementsManager(RequirementsManager):
 				"seed-intersphinx-mapping": ">=0.3.1",
 				"default-values": ">=0.4.2",
 				"toctree-plus": ">=0.1.0",
-				"sphinx-toolbox": ">=1.8.3",
+				"sphinx-toolbox": ">=2.2.0",
 				"sphinx-debuginfo": ">=0.1.0",
 				}
 
@@ -215,7 +214,10 @@ def make_rtfd(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 	python_config = {"version": 3.8, "install": install_config}
 
 	# Formats: Optionally build your docs in additional formats such as PDF and ePub
-	config = {"version": 2, "sphinx": sphinx_config, "formats": "all", "python": python_config}
+	config = {"version": 2, "sphinx": sphinx_config, "formats": ["pdf", "htmlzip"], "python": python_config}
+
+	# TODO: support user customisation of search rankings
+	# https://docs.readthedocs.io/en/stable/config-file/v2.html#search-ranking
 
 	dumper = yaml.YAML()
 	dumper.indent(mapping=2, sequence=3, offset=1)
@@ -352,7 +354,9 @@ def make_conf(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 			"sphinx_toolbox",
 			"sphinx_toolbox.more_autodoc",
 			"sphinx_toolbox.more_autosummary",
+			"sphinx_toolbox.documentation_summary",
 			"sphinx_toolbox.tweaks.param_dash",
+			"sphinx_toolbox.tweaks.latex_toc",
 			"sphinx.ext.intersphinx",
 			"sphinx.ext.mathjax",
 			"sphinxcontrib.httpdomain",
@@ -427,7 +431,7 @@ def make_alabaster_theming() -> str:
 
 	style: Dict[str, MutableMapping] = {
 			"li p:last-child": {"margin-bottom": dict2css.px(12)},
-			"html": {"scroll-behavior": "smooth"},  # Smooth scrolling between sections
+			# "html": {"scroll-behavior": "smooth"},  # Smooth scrolling between sections
 			"dl.class": class_border,
 			"dl.function": function_border,
 			"dl.function dt": {"margin-bottom": (dict2css.px(10), dict2css.IMPORTANT)},
@@ -483,7 +487,22 @@ def make_readthedocs_theming() -> str:
 	style: Dict[str, Mapping] = {
 			".wy-nav-content": {"max-width": (dict2css.px(1200), dict2css.IMPORTANT)},
 			"li p:last-child": {"margin-bottom": (dict2css.px(12), dict2css.IMPORTANT)},
-			"html": {"scroll-behavior": "smooth"},
+			# "html": {"scroll-behavior": "smooth"},
+			}
+
+	return dict2css.dumps(style, trailing_semicolon=True)
+
+
+def make_furo_theming() -> str:
+	"""
+	Make the custom stylesheet for the `Furo <https://github.com/pradyunsg/furo>`_ Sphinx theme.
+
+	:return: The custom stylesheet.
+	"""
+
+	style: Dict[str, Mapping] = {
+			"div.highlight": {"-moz-tab-size": 4, "tab-size": 4},
+			".field-list dt, dl.simple dt": {"margin-top": ".5rem"},
 			}
 
 	return dict2css.dumps(style, trailing_semicolon=True)
@@ -506,30 +525,19 @@ def copy_docs_styling(repo_path: pathlib.Path, templates: jinja2.Environment) ->
 	for directory in {style_css.parent, layout_html.parent}:
 		directory.maybe_make(parents=True)
 
-	if templates.globals["sphinx_html_theme"] == "sphinx-rtd-theme":
+	sphinx_html_theme = templates.globals["sphinx_html_theme"]
+	style_css_lines = [f"/* {templates.globals['managed_message']} */", '']
 
-		style_css.write_lines([
-				f"/* {templates.globals['managed_message']} */",
-				'',
-				make_readthedocs_theming(),
-				])
-	elif templates.globals["sphinx_html_theme"] == "alabaster":
-		style_css.write_lines([
-				f"/* {templates.globals['managed_message']} */",
-				'',
-				make_alabaster_theming(),
-				])
-	elif templates.globals["sphinx_html_theme"] == "furo":
-		style_css.write_lines([
-				f"/* {templates.globals['managed_message']} */",
-				'',
-				"div.highlight {",
-				"    -moz-tab-size: 4; /* Firefox */",
-				"    tab-size: 4;",
-				'}',
-				])
+	if sphinx_html_theme == "sphinx-rtd-theme":
+		style_css_lines.append(make_readthedocs_theming())
+	elif sphinx_html_theme == "alabaster":
+		style_css_lines.append(make_alabaster_theming())
+	elif sphinx_html_theme == "furo":
+		style_css_lines.append(make_furo_theming())
 	else:
-		style_css.write_clean('')
+		style_css_lines.clear()
+
+	style_css.write_lines(style_css_lines)
 
 	if templates.globals["sphinx_html_theme"] == "furo":
 		furo_navigation.parent.maybe_make()
@@ -620,8 +628,18 @@ def rewrite_docs_index(repo_path: pathlib.Path, templates: jinja2.Environment) -
 			on_pypi=templates.globals["on_pypi"],
 			primary_conda_channel=templates.globals["primary_conda_channel"],
 			)
+
 	sb.set_docs_mode()
-	shields_block = sb.make()
+	make_out = sb.make()
+
+	shield_block_list = StringList([*make_out[0:2], ".. only:: html"])
+
+	with shield_block_list.with_indent_size(1):
+		shield_block_list.extend(make_out[1:-1])
+
+	shield_block_list.append(make_out[-1])
+
+	shields_block = str(shield_block_list)
 
 	if templates.globals["license"] == "GNU General Public License v2 (GPLv2)":
 		source = f"https://img.shields.io/github/license/{templates.globals['username']}/{templates.globals['repo_name']}"
@@ -643,14 +661,15 @@ def rewrite_docs_index(repo_path: pathlib.Path, templates: jinja2.Environment) -
 			templates.globals["repo_name"],
 			)
 
-	short_desc_block = create_short_desc_block(templates.globals["short_desc"], )
-
 	# Do the replacement
 	index_rst = index_rst_file.read_text(encoding="UTF-8")
 	index_rst = shields_regex.sub(shields_block, index_rst)
 	index_rst = installation_regex.sub(install_block, index_rst)
 	index_rst = links_regex.sub(links_block, index_rst)
-	index_rst = short_desc_regex.sub(short_desc_block, index_rst)
+	index_rst = short_desc_regex.sub(
+			".. start short_desc\n\n.. documentation-summary::\n\n.. end short_desc",
+			index_rst,
+			)
 
 	index_rst_file.write_clean(index_rst)
 
