@@ -33,8 +33,8 @@ from operator import attrgetter
 from typing import Any, Dict, List, Tuple
 
 # 3rd party
+import dom_toml
 import jinja2
-import toml
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import DelimitedList
 from domdf_python_tools.typing import PathLike
@@ -51,7 +51,7 @@ from shippinglabel.requirements import (
 from repo_helper.configupdater2 import ConfigUpdater
 from repo_helper.files import management
 from repo_helper.files.linting import code_only_warning, lint_warn_list
-from repo_helper.utils import CustomTomlEncoder, IniConfigurator, indent_join
+from repo_helper.utils import IniConfigurator, indent_join
 
 __all__ = [
 		"make_tox",
@@ -205,7 +205,11 @@ class ToxConfig(IniConfigurator):
 		self._ini["tox"]["skip_missing_interpreters"] = True
 		self._ini["tox"]["isolated_build"] = True
 
-		tox_requires = {"pip>=20.3.3", "tox-envlist>=0.2.1", "tox-pip-version>=0.0.7", *self["tox_requirements"]}
+		tox_requires = {"pip>=20.3.3", "tox-pip-version>=0.0.7", *self["tox_requirements"]}
+
+		if self["pypi_name"] != "tox-envlist":
+			tox_requires.add("tox-envlist>=0.2.1")
+
 		self._ini["tox"]["requires"] = indent_join(sorted(tox_requires))
 
 	def envlists(self):
@@ -346,9 +350,7 @@ class ToxConfig(IniConfigurator):
 		self._ini["testenv:build"]["skip_install"] = True
 		self._ini["testenv:build"]["changedir"] = "{toxinidir}"
 		self._ini["testenv:build"]["deps"] = indent_join([
-				# "build[virtualenv]>=0.3.0",
-				"virtualenv",
-				"git+https://github.com/pypa/build",
+				"build[virtualenv]>=0.3.1",
 				"check-wheel-contents>=0.1.0",
 				"twine>=3.2.0",
 				*self["tox_build_requirements"],
@@ -379,27 +381,25 @@ class ToxConfig(IniConfigurator):
 			self._ini["testenv:lint"]["skip_install"] = True
 
 		self._ini["testenv:lint"]["deps"] = indent_join([
-				# "autopep8 >=1.5.2",
 				"flake8 >=3.8.2",
 				"flake8-2020 >= 1.6.0",
 				"flake8-builtins>=1.5.3",
 				"flake8-docstrings>=1.5.0",
 				"flake8-dunder-all>=0.1.1",
+				"flake8-encodings>=0.1.0",
 				"flake8-github-actions>=0.1.0",
 				"flake8-pyi>=20.10.0",
 				"flake8-pytest-style>=1.3.0",
+				"flake8-slots>=0.1.0",
 				"flake8-sphinx-links>=0.0.4",
 				"flake8-strftime>=0.1.1",
 				"flake8-typing-imports>=1.10.0",
-				"flake8-encodings>=0.1.0",
-				"flake8-slots>=0.1.0",
-				"git+https://github.com/PyCQA/pydocstyle@5118faa7173b0e5bbc230c4adf628758e13605bf",
 				"git+https://github.com/domdfcoding/flake8-quotes.git",
-				"git+https://github.com/domdfcoding/flake8-rst-docstrings.git",
 				"git+https://github.com/domdfcoding/flake8-rst-docstrings-sphinx.git",
+				"git+https://github.com/domdfcoding/flake8-rst-docstrings.git",
+				"pydocstyle>=6.0.0",
 				"pygments>=2.7.1",
 				])
-		# cmd = f"flake8 {' '.join(self.get_source_files())} --format=rst-toolbox"
 		cmd = f"python3 -m flake8_rst_docstrings_sphinx {' '.join(self.get_source_files())} --allow-toolbox {{posargs}}"
 		self._ini["testenv:lint"]["commands"] = cmd
 
@@ -491,6 +491,7 @@ class ToxConfig(IniConfigurator):
 		self._ini["flake8"]["multiline-quotes"] = '"""'
 		self._ini["flake8"]["docstring-quotes"] = '"""'
 		self._ini["flake8"]["count"] = True
+		self._ini["flake8"]["min_python_version"] = self["requires_python"]
 
 	def coverage_run(self):
 		"""
@@ -556,9 +557,12 @@ class ToxConfig(IniConfigurator):
 		``[pytest]``.
 		"""
 
-		self._ini["pytest"]["addopts"] = "--color yes --durations 25"
-		# --reruns 1 --reruns-delay 5
-		self._ini["pytest"]["timeout"] = 300
+		if self["enable_tests"]:
+			self._ini["pytest"]["addopts"] = "--color yes --durations 25"
+			# --reruns 1 --reruns-delay 5
+			self._ini["pytest"]["timeout"] = 300
+		else:
+			self._ini.remove_section("pytest")
 
 	def merge_existing(self, ini_file):
 		"""
@@ -703,7 +707,7 @@ def make_formate_toml(repo_path: pathlib.Path, templates: jinja2.Environment) ->
 	known_third_party.update(isort_config["known_third_party"])
 
 	if formate_file.is_file():
-		formate_config = toml.loads(formate_file.read_text())
+		formate_config = dom_toml.load(formate_file)
 	else:
 		formate_config = {}
 
@@ -747,7 +751,7 @@ def make_formate_toml(repo_path: pathlib.Path, templates: jinja2.Environment) ->
 	formate_config["config"] = config
 
 	formate_file = PathPlus(repo_path / "formate.toml")
-	formate_file.write_clean(toml.dumps(formate_config, encoder=CustomTomlEncoder(dict)))
+	dom_toml.dump(formate_config, formate_file, encoder=dom_toml.TomlEncoder)
 
 	return [formate_file.name, isort_file.name]
 
@@ -821,7 +825,7 @@ class TestsRequirementsManager(RequirementsManager):
 		if self._globals["pypi_name"] != "domdf_python_tools":
 			self.target_requirements.add(ComparableRequirement("domdf-python-tools[testing]>=2.0.1"))
 		if self._globals["pypi_name"] != "coincidence":
-			self.target_requirements.add(ComparableRequirement("coincidence>=0.1.0"))
+			self.target_requirements.add(ComparableRequirement("coincidence>=0.2.0"))
 
 	def merge_requirements(self) -> List[str]:
 		current_requirements, comments, invalid_lines = read_requirements(self.req_file, include_invalid=True)
